@@ -41,37 +41,52 @@ class ApiClient:
         url += f"/{endpoint}"
         return url
 
-    async def _make_request(self, endpoint, method, json_data=None, keep_none=False, headers=None):
+    async def _make_request(
+        self, endpoint, method, json_data=None, keep_none=False, headers=None, **kwargs
+    ):
         url = self._format_path(endpoint)
         data = self._delete_none(json_data or {}) if not keep_none else json_data or {}
         async with aiohttp.ClientSession() as session:
             _method = getattr(session, method)
             async with _method(
-                url, data=json.dumps(data, cls=self.json_encoder), headers=headers
+                url,
+                data=json.dumps(data, cls=self.json_encoder),
+                headers=headers,
+                **kwargs,
             ) as response:
                 body = await response.text()
                 result = json.loads(body, cls=self.json_decoder)
-                if result.get(self.error_field_name):
+                if self.error_field_name in result and self.error_text_field in result:
                     raise ApiException(result.get(self.error_text_field))
                 if self.result_wrapped_in_field:
                     return result[self.result_wrapped_in_field]
                 return result
 
-    async def get(self, endpoint, json_data=None, keep_none=False, headers=None):
+    async def get(self, endpoint, json_data=None, keep_none=False, headers=None, **kwargs):
         """Sends GET request to API."""
 
         return await self._make_request(
-            endpoint, "get", json_data=json_data, keep_none=keep_none, headers=headers
+            endpoint,
+            "get",
+            json_data=json_data,
+            keep_none=keep_none,
+            headers=headers,
+            **kwargs,
         )
 
-    async def post(self, endpoint, json_data=None, keep_none=False, headers=None):
+    async def post(self, endpoint, json_data=None, keep_none=False, headers=None, **kwargs):
         """Sends POST request to API."""
 
         return await self._make_request(
-            endpoint, "post", json_data=json_data, keep_none=keep_none, headers=headers
+            endpoint,
+            "post",
+            json_data=json_data,
+            keep_none=keep_none,
+            headers=headers,
+            **kwargs,
         )
 
-    async def delete(self, endpoint, json_data=None, keep_none=False, headers=None):
+    async def delete(self, endpoint, json_data=None, keep_none=False, headers=None, **kwargs):
         """Sends DELETE request to API."""
 
         return await self._make_request(
@@ -80,18 +95,29 @@ class ApiClient:
             json_data=json_data,
             keep_none=keep_none,
             headers=headers,
+            **kwargs,
         )
 
-    async def put(self, endpoint, json_data=None, keep_none=False, headers=None):
+    async def put(self, endpoint, json_data=None, keep_none=False, headers=None, **kwargs):
         """Sends PUT request to API."""
 
         return await self._make_request(
-            endpoint, "put", json_data=json_data, keep_none=keep_none, headers=headers
+            endpoint,
+            "put",
+            json_data=json_data,
+            keep_none=keep_none,
+            headers=headers,
+            **kwargs,
         )
 
-    async def patch(self, endpoint, json_data=None, keep_none=False, headers=None):
+    async def patch(self, endpoint, json_data=None, keep_none=False, headers=None, **kwargs):
         """Sends PATCH request to API."""
 
         return await self._make_request(
-            endpoint, "patch", json_data=json_data, keep_none=keep_none, headers=headers
+            endpoint,
+            "patch",
+            json_data=json_data,
+            keep_none=keep_none,
+            headers=headers,
+            **kwargs,
         )
