@@ -1,3 +1,5 @@
+"""Module with API response wrappers."""
+
 import json
 
 import aiohttp.web
@@ -6,7 +8,9 @@ from aiojsonapi.config import config
 
 
 class GoodResponse(aiohttp.web.Response):
-    def __init__(self, result, status_code=200, *args, **kwargs):
+    """Wrapper for good response result data."""
+
+    def __init__(self, result, *args, status_code=200, **kwargs):
         super().__init__(*args, **kwargs)
         self.body = json.dumps({"result": result, "error": False}, cls=config.json_encoder)
         self._status = status_code
@@ -14,7 +18,9 @@ class GoodResponse(aiohttp.web.Response):
 
 
 class BadResponse(aiohttp.web.Response):
-    def __init__(self, result, status_code=400, *args, **kwargs):
+    """Wrapper for bad response result data."""
+
+    def __init__(self, result, *args, status_code=400, **kwargs):
         super().__init__(*args, **kwargs)
         self.body = json.dumps({"error": True, "reason": result}, cls=config.json_encoder)
         self._status = status_code
